atlus API documentation

# atlus

`overturetoosm` is a Python package to convert objects tagged in the Overture schema for use in OSM. Only Overture's `places` layer is currently supported.

View Source

    1"""`overturetoosm` is a Python package to convert objects tagged in the
    2Overture schema for use in OSM. Only Overture's `places` layer is currently supported.
    3"""
    4
    5# SPDX-FileCopyrightText: 2024-present Will <wahubsch@gmail.com>
    6#
    7# SPDX-License-Identifier: MIT